==> openflowplugin-extension-nicira-0.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/of/tcp/dst/grouping/NxmOfTcpDst.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.tcp.dst.grouping;
import java.lang.Integer;
import javax.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.PortNumber;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmOfTcpDstGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-of-tcp-dst {
 *   leaf port {
 *     type inet:port-number;
 *   }
 *   leaf mask {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-of-tcp-dst-grouping/nxm-of-tcp-dst</i>
 *
 * <p>To create instances of this class use {@link NxmOfTcpDstBuilder}.
 * @see NxmOfTcpDstBuilder
 *
 */
public interface NxmOfTcpDst
    extends
    ChildOf<NxmOfTcpDstGrouping>,
    Augmentable<NxmOfTcpDst>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-of-tcp-dst");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.PortNumber</code> <code>port</code>, or <code>null</code> if not present
     */
    @Nullable
    PortNumber getPort();
    
    /**
     * @return <code>java.lang.Integer</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable
    Integer getMask();

}

==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/of/tcp/dst/grouping/NxmOfTcpDst.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.of.tcp.dst.grouping;
import java.lang.Integer;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.PortNumber;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmOfTcpDstGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-of-tcp-dst {
 *   leaf port {
 *     type inet:port-number;
 *   }
 *   leaf mask {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-of-tcp-dst-grouping/nxm-of-tcp-dst</i>
 *
 * <p>To create instances of this class use {@link NxmOfTcpDstBuilder}.
 * @see NxmOfTcpDstBuilder
 *
 */
public interface NxmOfTcpDst
    extends
    ChildOf<NxmOfTcpDstGrouping>,
    Augmentable<NxmOfTcpDst>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-of-tcp-dst");

    /**
     * @return <code>org.opendaylight.yang.gen.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.PortNumber</code> <code>port</code>, or <code>null</code> if not present
     */
    @Nullable PortNumber getPort();
    
    /**
     * @return <code>java.lang.Integer</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Integer getMask();

}
